@@ -4,13 +4,13 @@ use warnings;
 
 package Dist::Iller::Config;
 
-our $VERSION = '0.1401'; # VERSION
+our $VERSION = '0.1402';
 
 use Moose::Role;
 use MooseX::AttributeShortcuts;
 use namespace::autoclean;
 use Module::Load qw/load/;
-use Types::Standard qw/Str/;
+use Types::Standard qw/Bool Str/;
 use YAML::Tiny;
 use Path::Tiny;
 use Try::Tiny;
@@ -84,7 +84,7 @@ Dist::Iller::Config
 
 =head1 VERSION
 
-Version 0.1401, released 2016-02-05.
+Version 0.1402, released 2016-02-07.
 
 =head1 SOURCE
 
