@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Iller::Plugin;
 
-our $VERSION = '0.1401'; # VERSION
+our $VERSION = '0.1402';
 
 use Dist::Iller::Elk;
 use Types::Standard qw/Str Enum HashRef/;
@@ -30,6 +30,11 @@ has version => (
     isa => Str,
     default => '0',
 );
+has documentation => (
+    is => 'ro',
+    isa => Str,
+    predicate => 1,
+);
 has parameters => (
     is => 'ro',
     isa => HashRef,
@@ -71,6 +76,8 @@ sub merge_with {
 
 sub to_string {
     my $self = shift;
+    my %options = @_;
+
     my @strings = $self->has_base ? (sprintf '[%s / %s]' => $self->base, $self->plugin_name)
                 :                   (sprintf '[%s]' => $self->plugin_name)
                 ;
@@ -108,7 +115,7 @@ Dist::Iller::Plugin
 
 =head1 VERSION
 
-Version 0.1401, released 2016-02-05.
+Version 0.1402, released 2016-02-07.
 
 =head1 SOURCE
 
